pub struct Config {Show 17 fields
pub device_path: String,
pub enable_suspend: bool,
pub hci_command_timeout_seconds: u16,
pub le_active_scan_interval: u16,
pub le_active_scan_window: u16,
pub le_fast_adv_interval_max: u16,
pub le_fast_adv_interval_min: u16,
pub le_fast_adv_max_tx_power: i8,
pub le_slow_adv_interval_max: u16,
pub le_slow_adv_interval_min: u16,
pub le_slow_adv_max_tx_power: i8,
pub le_very_fast_adv_interval_max: u16,
pub le_very_fast_adv_interval_min: u16,
pub le_very_fast_adv_max_tx_power: i8,
pub legacy_pairing_enabled: bool,
pub override_vendor_capabilites_version: u16,
pub sco_offload_path_index: u8,
}Fields
device_path: Stringenable_suspend: boolhci_command_timeout_seconds: u16le_active_scan_interval: u16le_active_scan_window: u16le_fast_adv_interval_max: u16le_fast_adv_interval_min: u16le_fast_adv_max_tx_power: i8le_slow_adv_interval_max: u16le_slow_adv_interval_min: u16le_slow_adv_max_tx_power: i8le_very_fast_adv_interval_max: u16le_very_fast_adv_interval_min: u16le_very_fast_adv_max_tx_power: i8legacy_pairing_enabled: booloverride_vendor_capabilites_version: u16sco_offload_path_index: u8Implementations
Sourceimpl Config
impl Config
Sourcepub fn take_from_startup_handle() -> Self
pub fn take_from_startup_handle() -> Self
Take the config startup handle and parse its contents.
Panics
If the config startup handle was already taken or if it is not valid.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
Parse Self from bytes.
pub fn record_inspect(&self, inspector_node: &Node)